import request from '@/utils/request'

// 查询资产分类列表
export function listClassification(query) {
  return request({
    url: '/asset/classifications/list',
    method: 'get',
    params: query
  })
}

// 查询资产分类详情
export function getClassification(id) {
  return request({
    url: '/asset/classifications/' + id,
    method: 'get'
  })
}

// 新增资产分类
export function addClassification(data) {
  return request({
    url: '/asset/classifications/create',
    method: 'post',
    data: data
  })
}

// 修改资产分类
export function updateClassification(data) {
  return request({
    url: '/asset/classifications/update/' + data.id,
    method: 'post',
    data: data
  })
}

// 删除资产分类
export function delClassification(id, lastModUserId) {
  return request({
    url: '/asset/classifications/delete/' + id,
    method: 'post',
    params: lastModUserId ? { lastModUserId } : {}
  })
}

// 禁用资产分类
export function disableClassification(id, lastModUserId) {
  return request({
    url: '/asset/classifications/' + id + '/status/disable',
    method: 'post',
    params: lastModUserId ? { lastModUserId } : {}
  })
}

// 启用资产分类
export function enableClassification(id, lastModUserId) {
  return request({
    url: '/asset/classifications/' + id + '/status/enable',
    method: 'post',
    params: lastModUserId ? { lastModUserId } : {}
  })
}

// 批量删除资产分类
export function delClassificationBatch(ids, lastModUserId) {
  return request({
    url: '/asset/classifications/deleteBatch',
    method: 'post',
    data: ids,
    params: lastModUserId ? { lastModUserId } : {}
  })
}

// 获取资产分类树形结构
export function getClassificationTree(query) {
  return request({
    url: '/asset/classifications/tree',
    method: 'get',
    params: query
  })
}

// 根据父ID查询子分类
export function getChildClassifications(parentId, query) {
  
  return request({
    url: '/asset/classifications/children/' + parentId,
    method: 'get',
    params: query
  })
}

// 检查分类是否被使用
export function checkClassificationInUse(id) {
  return request({
    url: '/asset/classifications/' + id + '/check',
    method: 'get'
  })
}

// 导出资产分类
export function exportClassification(query) {
  
  return request({
    url: '/asset/classifications/export',
    method: 'get',
    params: query
  })
} 